@@ -1,12 +1,13 @@
 import itertools
 
 from .basic import identity
-from .enumerator import Enumerator
+
 
 class Enumerable(object):
+
     def __init__(self, iterator):
         self._iterator = iterator
-        
+
     def __iter__(self):
         return  self._iterator
 
@@ -23,11 +24,10 @@ class Enumerable(object):
 
             for value in self:
                 if n <= 0:
-                    raise StopIteration
+                    return
                 n -= 1
                 yield value
-            
-            raise StopIteration
+
         return Enumerable(next())
 
     @classmethod
@@ -40,12 +40,11 @@ class Enumerable(object):
                 value += 1
                 n -= 1
 
-            raise StopIteration
         return Enumerable(next())
 
     @classmethod
     def repeat(cls, value, count=None):
-        if not count is None:
+        if count is not None:
             return Enumerable(value for _ in range(count))
         return Enumerable(itertools.repeat(value))
 
@@ -53,4 +52,3 @@ class Enumerable(object):
     def for_each(cls, source, selector=None):
         selector = selector or identity
         return Enumerable(selector(value) for value in source)
-
