@@ -1,16 +1,14 @@
-from rx import Lock
-from rx.observable import Observable
+from rx import config
+from rx.core import Observer, ObservableBase, Disposable
 from rx.internal import DisposedException
-from rx.disposables import Disposable
-from rx.abstractobserver import AbstractObserver
 
 from .innersubscription import InnerSubscription
 
 
-class BehaviorSubject(Observable, AbstractObserver):
-    """Represents a value that changes over time. Observers can subscribe to
-    the subject to receive the last (or initial) value and all subsequent
-    notifications.
+class BehaviorSubject(ObservableBase, Observer):
+    """Represents a value that changes over time. Observers can
+    subscribe to the subject to receive the last (or initial) value and
+    all subsequent notifications.
     """
 
     def __init__(self, value):
@@ -19,10 +17,11 @@ class BehaviorSubject(Observable, AbstractObserver):
         specified value.
 
         Keyword parameters:
-        value -- Initial value sent to observers when no other value has been
-            received by the subject yet.
+        :param T value: Initial value sent to observers when no other
+            value has been received by the subject yet.
         """
-        super(BehaviorSubject, self).__init__(self.__subscribe)
+
+        super(BehaviorSubject, self).__init__()
 
         self.value = value
         self.observers = []
@@ -30,13 +29,13 @@ class BehaviorSubject(Observable, AbstractObserver):
         self.is_stopped = False
         self.exception = None
 
-        self.lock = Lock()
+        self.lock = config["concurrency"].RLock()
 
     def check_disposed(self):
         if self.is_disposed:
             raise DisposedException()
 
-    def __subscribe(self, observer):
+    def _subscribe_core(self, observer):
         ex = None
 
         with self.lock:
@@ -69,10 +68,8 @@ class BehaviorSubject(Observable, AbstractObserver):
             for o in os:
                 o.on_completed()
 
-
     def on_error(self, error):
-        """Notifies all subscribed observers with the exception."""
-
+        """Notifie all subscribed observers with the exception."""
         os = None
         with self.lock:
             self.check_disposed()
@@ -87,8 +84,7 @@ class BehaviorSubject(Observable, AbstractObserver):
                 o.on_error(error)
 
     def on_next(self, value):
-        """Notifies all subscribed observers with the value."""
-
+        """Notifie all subscribed observers with the value."""
         os = None
         with self.lock:
             self.check_disposed()
@@ -100,14 +96,13 @@ class BehaviorSubject(Observable, AbstractObserver):
                 o.on_next(value)
 
     def dispose(self):
-        """Releases all resources used by the current instance of the
-        ReplaySubject class and unsubscribe all observers."""
+        """Release all resources.
 
+        Releases all resources used by the current instance of the
+        ReplaySubject class and unsubscribe all observers.
+        """
         with self.lock:
             self.is_disposed = True
             self.observers = None
             self.value = None
             self.exception = None
-
-
-
